package ru.indvdum.mywork.vaadin;

import static ru.indvdum.mywork.MyWork.EM;

import java.util.List;

import javax.persistence.Query;

import ru.indvdum.mywork.openjpa.model.Day;
import ru.indvdum.mywork.openjpa.model.Task;
import ru.indvdum.mywork.openjpa.model.Work;

import com.vaadin.Application;
import com.vaadin.addon.jpacontainer.EntityContainer;
import com.vaadin.addon.jpacontainer.EntityProvider;
import com.vaadin.addon.jpacontainer.HierarchicalEntityContainer;
import com.vaadin.addon.jpacontainer.JPAContainer;
import com.vaadin.addon.jpacontainer.provider.BatchableLocalEntityProvider;
import com.vaadin.addon.jpacontainer.provider.CachingBatchableLocalEntityProvider;
import com.vaadin.addon.jpacontainer.provider.CachingLocalEntityProvider;
import com.vaadin.addon.jpacontainer.provider.CachingMutableLocalEntityProvider;
import com.vaadin.addon.jpacontainer.provider.LocalEntityProvider;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.MenuBar;
import com.vaadin.ui.TabSheet;
import com.vaadin.ui.Table;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.Window;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.Button.ClickListener;
import com.vaadin.ui.MenuBar.Command;
import com.vaadin.ui.MenuBar.MenuItem;

/**
 * @author indvdum
 * 12.08.2011 17:31:53
 *
 */
public class MyWorkApplication extends Application {
	
	private MyWorkApplication thisObject = this;
	private Table dayTable = null;
	private Table taskTable = null;
	private Table workTable = null;
	
	private Command newDayCommand = new Command() {
        public void menuSelected(MenuItem selectedItem) {
        	EditDayDialog dialog = null;
			try {
				dialog = new EditDayDialog(thisObject, EditState.CREATE, null);
			} catch (Exception e) {
				e.printStackTrace();
			}
            getMainWindow().addWindow(dialog);
        }
    };
    private Command newTaskCommand = new Command() {
    	public void menuSelected(MenuItem selectedItem) {
    		EditTaskDialog dialog = null;
    		try {
    			dialog = new EditTaskDialog(thisObject, EditState.CREATE, null);
    		} catch (Exception e) {
    			e.printStackTrace();
    		}
    		getMainWindow().addWindow(dialog);
    	}
    };
    private Command newWorkCommand = new Command() {
    	public void menuSelected(MenuItem selectedItem) {
    		EditWorkDialog dialog = null;
    		try {
    			dialog = new EditWorkDialog(thisObject, EditState.CREATE, null);
    		} catch (Exception e) {
    			e.printStackTrace();
    		}
    		getMainWindow().addWindow(dialog);
    	}
    };

	@Override
	public void init() {
		Window window = new Window();
		setMainWindow(window);
		
		TabSheet tabSheet = new TabSheet();
		tabSheet.setSizeFull();
		window.setContent(tabSheet);
		
		VerticalLayout vlMain = new VerticalLayout();
		vlMain.setSizeFull();
		vlMain.setMargin(true);
		vlMain.setSpacing(true);
		tabSheet.addTab(vlMain, "Main page", null);
		
		MenuBar menubar = new MenuBar();
		MenuItem file = menubar.addItem("File", null);
		MenuItem newItem = file.addItem("New", null);
		newItem.addItem("Day...", newDayCommand);
        newItem.addItem("Task...", newTaskCommand);
        newItem.addItem("Work...", newWorkCommand);
        vlMain.addComponent(menubar);
		
		LocalEntityProvider dayProvider = new CachingLocalEntityProvider(Day.class);
		dayProvider.setEntityManager(EM);
		JPAContainer<Day> dayContainer = new JPAContainer(Day.class);
		dayContainer.setEntityProvider(dayProvider);
		
		dayTable = new Table();
		dayTable.setSelectable(true);
		dayTable.setEditable(false);
		dayTable.setImmediate(true);
		dayTable.setSizeFull();
		dayTable.setContainerDataSource(dayContainer);
		dayTable.setVisibleColumns(new String[]{
				"day",
				"startWork",
				"endWork",
				"hours",
		});
		vlMain.addComponent(dayTable);
		vlMain.setExpandRatio(dayTable, 1f);
		
		LocalEntityProvider taskProvider = new CachingLocalEntityProvider(Task.class);
		taskProvider.setEntityManager(EM);
		JPAContainer<Task> taskContainer = new JPAContainer(Task.class);
		taskContainer.setEntityProvider(taskProvider);
		
		taskTable = new Table();
		taskTable.setSelectable(true);
		taskTable.setEditable(false);
		taskTable.setImmediate(true);
		taskTable.setSizeFull();
		taskTable.setContainerDataSource(taskContainer);
		taskTable.setVisibleColumns(new String[]{
				"name",
				"description",
		});
		taskTable.setColumnWidth("description", 300);
		vlMain.addComponent(taskTable);
		vlMain.setExpandRatio(taskTable, 1f);
		
		LocalEntityProvider workProvider = new CachingLocalEntityProvider(Work.class);
		workProvider.setEntityManager(EM);
		JPAContainer<Task> workContainer = new JPAContainer(Work.class);
		workContainer.setEntityProvider(workProvider);
		
		workTable = new Table();
		workTable.setSelectable(true);
		workTable.setEditable(false);
		workTable.setImmediate(true);
		workTable.setSizeFull();
		workTable.setContainerDataSource(workContainer);
		workTable.setVisibleColumns(new String[]{
				"day",
				"task",
				"hours",
				"result",
		});
		workTable.setColumnWidth("result", 200);
		vlMain.addComponent(workTable);
		vlMain.setExpandRatio(workTable, 1f);
	}

	public Table getDayTable() {
		return dayTable;
	}

	public Table getTaskTable() {
		return taskTable;
	}

	public Table getWorkTable() {
		return workTable;
	}
}
